Photometric lighting based on Eulumdat data
Since Bevy doesn’t have native IES/photometric light support, we simulate it using spot lights or by calculating illuminance on surfaces.
Photometric lighting based on Eulumdat data
Since Bevy doesn’t have native IES/photometric light support, we simulate it using spot lights or by calculating illuminance on surfaces.